(function ($, Drupal) {
  Drupal.behaviors.simpleFavsBlockRender = {
    attach: function (context, settings) {
      once('simple-favs-render', '[data-block-plugin-id="simple_favs_block"]', context).forEach(function (block) {
        const favs = Drupal.behaviors.simpleFavs.getFavs();
        const $block = $(block);

        const wrapper_prefix = drupalSettings.simple_favs.block.wrapper_prefix || '';

        const title_prefix = drupalSettings.simple_favs.block.title_prefix || '';
        const title_suffix = drupalSettings.simple_favs.block.title_suffix || '';

        const fallback_prefix = drupalSettings.simple_favs.block.fallback_prefix || '';
        const fallback_suffix = drupalSettings.simple_favs.block.fallback_suffix || '';

        const wrapper_suffix = drupalSettings.simple_favs.block.wrapper_suffix || '';

        const title_classes = drupalSettings.simple_favs.block.title_classes || '';
        const langcode = drupalSettings.simple_favs.block.langcode || 'und';
        const list_classes = drupalSettings.simple_favs.block.favs_list_classes || '';

        if ($block.length) {
          $block.empty();
          const keys = Object.keys(favs);
          if (keys.length === 0) {
            $block.append(wrapper_prefix + title_prefix + '<h2 class="simple-favs' + title_classes + '">' + Drupal.t('My Favourites') + '</h2>' + title_suffix + fallback_prefix + '<p class="' + list_classes + '">' + Drupal.t('There currently are no selected favourites.') + '</p>' + fallback_suffix + wrapper_suffix);
          }
          else {
            $.getJSON('/simple-favs/titles', {
              ids: keys,
              langcode: langcode,
            }, function (titleMap) {
              const $ul = $('<ul class="simple-favs-list ' + list_classes + '"></ul>');

              keys.forEach(function (id) {
                const title = titleMap[id] || 'Content ID: ' + id;
                const url = (langcode !== 'und') ? '/' + langcode + '/node/' + id : null;

                let $item;
                if (url) {
                  const $link = $('<a></a>')
                    .attr('href', url)
                    .text(title);
                  $item = $('<li></li>').append($link);
                }
                else {
                  $item = $('<li></li>').text(title);
                }

                $ul.append($item);
              });
              let fallback = '';

              const ulHtml = $ul.prop('outerHTML');

              if (fallback_prefix && fallback_suffix) {
                fallback = fallback_prefix + ulHtml + fallback_suffix;
              }
              else {
                fallback = '<div>' + ulHtml + '</div>';
              }
              const $wrappedList = $(fallback);

              const $titleHtml = $('<h2 class="simple-favs-block ' + title_classes + '">' + Drupal.t('My Favourites') + '</h2>');
              const rawTitleHtml = $titleHtml.prop('outerHTML');
              // Insert title
              if (title_prefix && title_suffix) {
                $title = $(title_prefix + rawTitleHtml + title_suffix);
              }
              else {
                $title = $('<div>' + rawTitleHtml + '</div>');
              }
              $wrappedList.prepend($title);

              // Convert $wrappedList to HTML.
              const wrappedHtml = $wrappedList.prop('outerHTML');

              // Wrap it if prefix/suffix are defined.
              let finalOutput = '';
              if (wrapper_prefix || wrapper_suffix) {
                finalOutput = wrapper_prefix + wrappedHtml + wrapper_suffix;
              }
              else {
                finalOutput = wrappedHtml;
              }

              // Inject into block.
              $block.prepend(finalOutput);
            });
          }
        }
      });
    }
  };
})(jQuery, Drupal);

