<?php

namespace Drupal\simple_favs\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class SimpleFavsSettingsForm.
 */
class SimpleFavsSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'simple_favs.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'simple_favs_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('simple_favs.settings');
    $form['block_display'] = [
      '#type' => 'details',
      '#title' => $this->t('Block display settings'),
      '#open' => TRUE,
    ];

    $form['block_display']['wrapper_prefix'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Wrapper prefix'),
      '#description' => $this->t('Optional markup to add before the title and fallback.'),
      '#default_value' => $config->get('wrapper_prefix') ?? '',
    ];

    $form['block_display']['title_prefix'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Title prefix'),
      '#default_value' => $config->get('title_prefix') ?? '',
    ];

    $form['block_display']['title_suffix'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Title suffix'),
      '#default_value' => $config->get('title_suffix') ?? '',
    ];

    $form['block_display']['fallback_prefix'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Fallback prefix'),
      '#default_value' => $config->get('fallback_prefix') ?? '',
    ];

    $form['block_display']['fallback_suffix'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Fallback suffix'),
      '#default_value' => $config->get('fallback_suffix') ?? '',
    ];

    $form['cookie_expiration'] = [
      '#type' => 'number',
      '#title' => $this->t('Cookie expiration'),
      '#description' => $this->t('Please, set how many days the cookie with the favourites information should be stored.'),
      '#default_value' => $config->get('cookie_expiration'),
    ];

    $form['block_display']['wrapper_suffix'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Wrapper suffix'),
      '#description' => $this->t('Optional markup to add after the title and fallback.'),
      '#default_value' => $config->get('wrapper_suffix') ?? '',
    ];

    $form['use_database_storage'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Use database storage instead of cookies'),
      '#default_value' => $config->get('use_database_storage'),
      '#description' => $this->t('If enabled, favourites will be stored in the database for authenticated users. Anonymous users will still use cookies.'),
    ];

    $form['block_display']['title_classes'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Additional title classes'),
      '#description' => $this->t('Space-separated CSS class names to add to the &lt;h2&gt; title element.'),
      '#default_value' => $config->get('title_classes') ?? '',
    ];

    $form['block_display']['favs_list_classes'] = [
     '#type' => 'textfield',
     '#title' => $this->t('Favourites list classes'),
     '#default_value' => $config->get('favs_list_classes'),
     '#description' => $this->t('Additional classes to apply to the &lt;ul&gt; element in the My Favourites block. Separate with spaces.'),
   ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    $this->config('simple_favs.settings')
      ->set('cookie_expiration', $form_state->getValue('cookie_expiration'))
      ->set('use_database_storage', $form_state->getValue('use_database_storage'))
      ->set('wrapper_prefix', $form_state->getValue('wrapper_prefix'))
      ->set('title_prefix', $form_state->getValue('title_prefix'))
      ->set('title_suffix', $form_state->getValue('title_suffix'))
      ->set('fallback_prefix', $form_state->getValue('fallback_prefix'))
      ->set('fallback_suffix', $form_state->getValue('fallback_suffix'))
      ->set('wrapper_suffix', $form_state->getValue('wrapper_suffix'))
      ->set('title_classes', $form_state->getValue('title_classes'))
      ->set('favs_list_classes', $form_state->getValue('favs_list_classes'))
      ->save();
  }

}
