<?php

namespace Drupal\simple_favs\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\Language\LanguageInterface;

/**
 * Provides a "My Favourites" block for Simple Favs.
 *
 * @Block(
 *   id = "simple_favs_block",
 *   admin_label = @Translation("Simple Favs"),
 * )
 */
class SimpleFavsBlock extends BlockBase {
  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public function build() {
    $config = \Drupal::config('simple_favs.settings');

    $wrapper_prefix = $config->get('wrapper_prefix') ?? '';
    $wrapper_suffix = $config->get('wrapper_suffix') ?? '';
    $title_prefix = $config->get('title_prefix') ?? '';
    $title_suffix = $config->get('title_suffix') ?? '';
    $fallback_prefix = $config->get('fallback_prefix') ?? '';
    $fallback_suffix = $config->get('fallback_suffix') ?? '';
    $title_classes = $config->get('title_classes') ?? '';
    $favs_list_classes = $config->get('favs_list_classes') ?? '';

    // Safe fallback for language (supports single-language sites).
    $langcode = 'und';
    if (\Drupal::hasService('language_manager')) {
      $language = \Drupal::languageManager()->getCurrentLanguage(LanguageInterface::TYPE_INTERFACE);
      if ($language && $language->getId()) {
        $langcode = $language->getId();
      }
    }

    return [
      '#type' => 'container',
      '#attributes' => [
        'data-block-plugin-id' => 'simple-favs-block',
        'class' => ['simple-favs-wrapper'],
      ],
      'prefix' => ['#markup' => $wrapper_prefix],
      'title' => [
        '#markup' => $title_prefix . '<h2 class="simple-favs-block ' . $title_classes . '">' . $this->t('My Favourites') . '</h2>' . $title_suffix,
      ],
      'fallback' => [
        '#markup' => $fallback_prefix . '<p class="' . $favs_list_classes . '">' . $this->t('There currently are no selected favourites.') . '</p>' . $fallback_suffix,
      ],
      'suffix' => ['#markup' => $wrapper_suffix],
      '#attached' => [
        'library' => ['simple_favs/favs'],
        'drupalSettings' => [
          'simple_favs' => [
            'block' => [
              'title_prefix' => $title_prefix,
              'title_suffix' => $title_suffix,
              'fallback_prefix' => $fallback_prefix,
              'fallback_suffix' => $fallback_suffix,
              'wrapper_prefix' => $wrapper_prefix,
              'wrapper_suffix' => $wrapper_suffix,
              'title_classes' => $title_classes,
              'favs_list_classes' => $favs_list_classes,
              'langcode' => $langcode,
            ],
          ],
        ],
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheTags() {
    // Ensures config changes invalidate this block too.
    return ['config:simple_favs.settings'];
  }

}

